@@ -15,8 +15,8 @@ sub new {
         %args = @_;
     }
     my $deadline_ms = $args{deadline_ms} // die 'deadine_ms is required';
-    my $invoked_function_arn = $args{invoked_function_arn} // die 'invoked_function_arn is required';
-    my $aws_request_id = $args{aws_request_id} // 'aws_request_id is required';
+    my $invoked_function_arn = $args{invoked_function_arn} // '';
+    my $aws_request_id = $args{aws_request_id} // '';
     my $trace_id = $args{trace_id};
     my $self = bless +{
         deadline_ms          => +$deadline_ms,
